@@ -1,18 +1,24 @@
 package Method::Generate::BuildAll;
+use strict;
+use warnings;
 
-use Moo::_strictures;
 use Moo::Object ();
-our @ISA = qw(Moo::Object);
+BEGIN { our @ISA = qw(Moo::Object) }
 use Sub::Quote qw(quote_sub quotify);
-use Moo::_Utils qw(_getglob);
+use Moo::_Utils qw(_getglob _linear_isa);
 
 sub generate_method {
   my ($self, $into) = @_;
-  quote_sub "${into}::BUILDALL", join '',
-    $self->_handle_subbuild($into),
-    qq{    my \$self = shift;\n},
-    $self->buildall_body_for($into, '$self', '@_'),
-    qq{    return \$self\n};
+  quote_sub "${into}::BUILDALL"
+    => join('',
+      $self->_handle_subbuild($into),
+      qq{    my \$self = shift;\n},
+      $self->buildall_body_for($into, '$self', '@_'),
+      qq{    return \$self\n},
+    )
+    => {}
+    => { no_defer => 1 }
+  ;
 }
 
 sub _handle_subbuild {
@@ -27,7 +33,7 @@ sub buildall_body_for {
   my @builds =
     grep *{_getglob($_)}{CODE},
     map "${_}::BUILD",
-    reverse @{mro::get_linear_isa($into)};
+    reverse @{_linear_isa($into)};
   '    (('.$args.')[0]->{__no_BUILD__} or ('."\n"
   .join('', map qq{      ${me}->${_}(${args}),\n}, @builds)
   ."    )),\n";
