@@ -1,10 +1,10 @@
 package Method::Generate::Constructor;
+use strict;
+use warnings;
 
-use Moo::_strictures;
 use Sub::Quote qw(quote_sub quotify);
 use Sub::Defer;
-use Moo::_Utils qw(_getstash _getglob);
-use Moo::_mro;
+use Moo::_Utils qw(_getstash _getglob _linear_isa);
 use Scalar::Util qw(weaken);
 use Carp qw(croak);
 use Carp::Heavy ();
@@ -19,26 +19,16 @@ sub register_attribute_specs {
   my ($self, @new_specs) = @_;
   $self->assert_constructor;
   my $specs = $self->{attribute_specs}||={};
+  my $ag = $self->accessor_generator;
   while (my ($name, $new_spec) = splice @new_specs, 0, 2) {
     if ($name =~ s/^\+//) {
-      croak "has '+${name}' given but no ${name} attribute already exists"
-        unless my $old_spec = $specs->{$name};
-      foreach my $key (keys %$old_spec) {
-        if (!exists $new_spec->{$key}) {
-          $new_spec->{$key} = $old_spec->{$key}
-            unless $key eq 'handles';
-        }
-        elsif ($key eq 'moosify') {
-          $new_spec->{$key} = [
-            map { ref $_ eq 'ARRAY' ? @$_ : $_ }
-              ($old_spec->{$key}, $new_spec->{$key})
-          ];
-        }
-      }
+      my $old_spec = $specs->{$name}
+        or croak "has '+${name}' given but no ${name} attribute already exists";
+      $ag->merge_specs($new_spec, $old_spec);
     }
     if ($new_spec->{required}
       && !(
-        $self->accessor_generator->has_default($name, $new_spec)
+        $ag->has_default($name, $new_spec)
         || !exists $new_spec->{init_arg}
         || defined $new_spec->{init_arg}
       )
@@ -85,11 +75,11 @@ sub install_delayed {
   my ($self) = @_;
   $self->assert_constructor;
   my $package = $self->{package};
-  my (undef, @isa) = @{mro::get_linear_isa($package)};
+  my (undef, @isa) = @{_linear_isa($package)};
   my $isa = join ',', @isa;
   my (undef, $from_file, $from_line) = caller(Carp::short_error_loc());
   my $constructor = defer_sub "${package}::new" => sub {
-    my (undef, @new_isa) = @{mro::get_linear_isa($package)};
+    my (undef, @new_isa) = @{_linear_isa($package)};
     if (join(',', @new_isa) ne $isa) {
       my ($expected_new) = grep { *{_getglob($_.'::new')}{CODE} } @isa;
       my ($found_new) = grep { *{_getglob($_.'::new')}{CODE} } @new_isa;
@@ -241,8 +231,8 @@ sub _check_required {
   my @required_init =
     map $spec->{$_}{init_arg},
       grep {
-        my %s = %{$spec->{$_}}; # ignore required if default or builder set
-        $s{required} and not($s{builder} or exists $s{default})
+        my $s = $spec->{$_}; # ignore required if default or builder set
+        $s->{required} and not($s->{builder} or exists $s->{default})
       } sort keys %$spec;
   return '' unless @required_init;
   '    if (my @missing = grep !exists $args->{$_}, '
